@@ -14,25 +14,27 @@ def start(
     name=None,
     args=None,
     sudo=False,
+    sudo_options=None,
     options=None,
     capture=False,
     singularity_options=None,
+    environ=None,
 ):
     """start an instance. This is done by default when an instance is created.
 
-       Parameters
-       ==========
-       image: optionally, an image uri (if called as a command from Client)
-       name: a name for the instance
-       sudo: if the user wants to run the command with sudo
-       capture: capture output, default is False. With True likely to hang.
-       args: arguments to provide to the instance (supported Singularity 3.1+)
-       singularity_options: a list of options to provide to the singularity client
-       options: a list of tuples, each an option to give to the start command
-                [("--bind", "/tmp"),...]
+    Parameters
+    ==========
+    image: optionally, an image uri (if called as a command from Client)
+    name: a name for the instance
+    sudo: if the user wants to run the command with sudo
+    capture: capture output, default is False. With True likely to hang.
+    args: arguments to provide to the instance (supported Singularity 3.1+)
+    singularity_options: a list of options to provide to the singularity client
+    options: a list of tuples, each an option to give to the start command
+             [("--bind", "/tmp"),...]
 
-       USAGE: 
-       singularity [...] instance.start [...] <container path> <instance name>
+    USAGE:
+    singularity [...] instance.start [...] <container path> <instance name>
 
     """
     from spython.utils import run_command, check_install
@@ -77,7 +79,14 @@ def start(
     self.args = args
     self.cmd = cmd
 
-    output = run_command(cmd, sudo=sudo, quiet=True, capture=capture)
+    output = run_command(
+        cmd,
+        sudo=sudo,
+        sudo_options=sudo_options,
+        quiet=True,
+        capture=capture,
+        environ=environ,
+    )
 
     if output["return_code"] == 0:
         self._update_metadata()
