@@ -15,26 +15,27 @@ def list_instances(
     return_json=False,
     quiet=False,
     sudo=False,
+    sudo_options=None,
     singularity_options=None,
 ):
     """list instances. For Singularity, this is provided as a command sub
-       group.
+    group.
 
-       singularity instance.list
+    singularity instance.list
 
-       Return codes provided are different from standard linux:
-       see https://github.com/singularityware/singularity/issues/1706
+    Return codes provided are different from standard linux:
+    see https://github.com/singularityware/singularity/issues/1706
 
-       Parameters
-       ==========
-       return_json: return a json list of instances instead of objects (False)
-       name: if defined, return the list for just one instance (used to ged pid)
-       singularity_options: a list of options to provide to the singularity client
+    Parameters
+    ==========
+    return_json: return a json list of instances instead of objects (False)
+    name: if defined, return the list for just one instance (used to ged pid)
+    singularity_options: a list of options to provide to the singularity client
 
-       Return Code  --   Reason
-       0 -- Instances Found
-       1 -- No Instances, libexecdir value not found, functions file not found
-       255 -- Couldn't get UID
+    Return Code  --   Reason
+    0 -- Instances Found
+    1 -- No Instances, libexecdir value not found, functions file not found
+    255 -- Couldn't get UID
 
     """
     from spython.instance.cmd.iutils import parse_table
@@ -53,7 +54,7 @@ def list_instances(
     if name is not None:
         cmd.append(name)
 
-    output = run_command(cmd, quiet=True, sudo=sudo)
+    output = run_command(cmd, quiet=True, sudo=sudo, sudo_options=sudo_options)
     instances = []
 
     # Success, we have instances
@@ -113,12 +114,12 @@ def list_instances(
 
 def stopall(self, sudo=False, quiet=True, singularity_options=None):
     """stop ALL instances. This command is only added to the command group
-       as it doesn't make sense to call from a single instance
+    as it doesn't make sense to call from a single instance
 
-       Parameters
-       ==========
-       sudo: if the command should be done with sudo (exposes different set of
-             instances)
+    Parameters
+    ==========
+    sudo: if the command should be done with sudo (exposes different set of
+          instances)
 
     """
     from spython.utils import check_install
